@@ -13,28 +13,6 @@ setGeneric("encode", function(.Object, ...) standardGeneric("encode"))
 #' @param indexedCorpusDir directory where to create directory for indexed corpus files
 #' @param verbose logical, whether to be verbose
 #' @param ... further parameters
-#' @examples 
-#' \dontrun{
-#' library(tm)
-#' library(tibble)
-#' library(tidytext)
-#' library(plyr)
-#' reut21578 <- system.file("texts", "crude", package = "tm")
-#' reuters.tm <- VCorpus(DirSource(reut21578), list(reader = readReut21578XMLasPlain))
-#' reuters.tibble <- tidy(reuters.tm)
-#' # reuters.tibble[["topics_cat"]] <- sapply(
-#'   reuters.tibble[["topics_cat"]],
-#'   function(x) paste(x, collapse = "|")
-#' )
-#' reuters.tibble[["places"]] <- sapply(
-#'  reuters.tibble[["places"]],
-#'  function(x) paste(x, collapse = "|")
-#' )
-#' reuters.tidy <- unnest_tokens(
-#'   reuters.tibble, output = "word", input = "text", to_lower = FALSE
-#'   )
-#' encode(reuters.tidy, name = "reuters", sAttributes = c("language", "places"))
-#' }
 #' @rdname encode-method
 #' @exportMethod encode
 setMethod("encode", "data.frame", function(
@@ -152,7 +130,7 @@ setMethod("encode", "data.table", function(.Object, corpus, sAttribute){
   
   cmd <- c(
     "cwb-s-encode",
-    "-d", parseRegistry(corpus)[["HOME"]],
+    "-d", RegistryFile$new(corpus)$getHome(),
     "-f", tmp_file,
     "-V", sAttribute
   )
