@@ -47,10 +47,10 @@ setMethod(
     ){
   if (requireNamespace("markdown", quietly=TRUE) && requireNamespace("htmltools", quietly=TRUE)){
     if (all(meta %in% sAttributes(object)) != TRUE) warning("not all sAttributes provided as meta are available")
-    if (verbose == TRUE) message("... enriching partition with metadata")
+    if (verbose) message("... enriching partition with metadata")
     object <- enrich(object, meta = meta, verbose=FALSE)
-    if (verbose == TRUE) message("... generating markdown")
-    if (any(cqp) == TRUE) cpos <- TRUE
+    if (verbose) message("... generating markdown")
+    if (any(cqp)) cpos <- TRUE
     markdown <- as.markdown(object, meta = meta, cpos = cpos, cutoff = cutoff, ...)
     markdown <- paste(
       paste('## Corpus: ', object@corpus, '\n* * *\n\n'),
@@ -131,10 +131,10 @@ setMethod("html", "kwic", function(object, i, type = NULL, verbose = FALSE){
   
   # getting metadata for all kwic lines is potentially not the fastes solution ...
   if (length(object@metadata) == 0){
-    metadataDef <- get(".templates", envir = .GlobalEnv)[[object@corpus]][["metadata"]]
+    metadataDef <- getOption("polmineR.templates")[[object@corpus]][["metadata"]]
     if (verbose) message("... using metadata from template: ", metadataDef)
     if (length(metadataDef) > 0){
-      if (verbose) message("... enrichting")
+      if (verbose) message("... enriching")
       object <- enrich(object, meta = metadataDef)
     }
   }
@@ -149,8 +149,8 @@ setMethod("html", "kwic", function(object, i, type = NULL, verbose = FALSE){
   fulltext <- highlight(
     fulltext,
     highlight = list(
-      yellow = c(object@cpos[[i]][["left"]], object@cpos[[i]][["right"]]),
-      lightgreen = object@cpos[[i]][["node"]]
+      yellow = object@cpos[which(object@cpos[["hit_no"]] == i)][which(object@cpos[["position"]] != 0)][["cpos"]],
+      lightgreen = object@cpos[which(object@cpos[["hit_no"]] == i)][which(object@cpos[["position"]] != 0)][["cpos"]]
     )
   )
   fulltext
